==> haskell-hjsmin-0.1.5.1-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-hjsmin/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hjsmin
version: 0.1.5.1
id: hjsmin-0.1.5.1-1b718142efced76f4fbd2dca7056fef1
key: hjsmi_HS0EBcal0cj8ADxeQnC5Ss
license: BSD3
maintainer: Erik de Castro Lopo <erikd@mega-nerd.com>
stability: unstable
homepage: http://github.com/erikd/hjsmin
synopsis: Haskell implementation of a javascript minifier
description:
    Reduces size of javascript files by stripping out extraneous whitespace and
    other syntactic elements, without changing the semantics.
category: Web
author: Alan Zimmerman <alan.zimm@gmail.com>
exposed: True
exposed-modules:
    Text.Jasmine
hidden-modules: Text.Jasmine.Pretty
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/hjsmin-0.1.5.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/hjsmin-0.1.5.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/hjsmin-0.1.5.1
hs-libraries: HShjsmin-0.1.5.1-HS0EBcal0cj8ADxeQnC5Ss
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    language-javascript-0.5.14.2-f55c8cd80a337ed6a6cb1df128d3b4c5
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
haddock-interfaces: /usr/share/doc/haskell-hjsmin/html/hjsmin.haddock
haddock-html: /usr/share/doc/haskell-hjsmin/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hjsmin-0.1.5.2-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-hjsmin/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hjsmin
version: 0.1.5.2
id: hjsmin-0.1.5.2-1047ccfd810ad2476389611e596c4ae2
key: hjsmi_FBBK0TbYJu3AK4W3F3fpqz
license: BSD3
maintainer: Erik de Castro Lopo <erikd@mega-nerd.com>
stability: unstable
homepage: http://github.com/erikd/hjsmin
synopsis: Haskell implementation of a javascript minifier
description:
    Reduces size of javascript files by stripping out extraneous whitespace and
    other syntactic elements, without changing the semantics.
category: Web
author: Alan Zimmerman <alan.zimm@gmail.com>
exposed: True
exposed-modules:
    Text.Jasmine
hidden-modules: Text.Jasmine.Pretty
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/hjsmin-0.1.5.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/hjsmin-0.1.5.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/hjsmin-0.1.5.2
hs-libraries: HShjsmin-0.1.5.2-FBBK0TbYJu3AK4W3F3fpqz
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    language-javascript-0.5.14.2-f55c8cd80a337ed6a6cb1df128d3b4c5
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
haddock-interfaces: /usr/share/doc/haskell-hjsmin/html/hjsmin.haddock
haddock-html: /usr/share/doc/haskell-hjsmin/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
